.. automodule:: Orange.bio.ontology

.. autoclass:: OBOOntology
   :members:
   :member-order: bysource
   :show-inheritance:

.. autoclass:: OBOObject
   :members:
   :member-order: bysource
   :show-inheritance:

.. autoclass:: Term
   :members:
   :member-order: bysource
   :show-inheritance:

.. autoclass:: Typedef
   :members:
   :member-order: bysource
   :show-inheritance:

.. autoclass:: Instance
   :members:
   :member-order: bysource
   :show-inheritance:

.. autoclass:: OBOParser
   :members:
   :member-order: bysource
